==> viha-5.15.tar.gz: viha-5.15/hlo-oper.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "hlo";
$file = basename(__FILE__);

include "common.php";
include "hlo-ok.php";

echo "
<html>
<head>
 <title>VIHA - Operaation miehittminen</title>
</head>
" . body_bgcolor() . "
<h1>" . ota_paivystys_nimi() . ", operaation miehittminen</h1>
";

taktiset_linkit();

$id = get_nro_0('id');

$take = get_txt('take');
$release = get_txt('release');
$show = get_nro('show');

# kuka vaan voi ottaa henkiln alueeltaan - kytettvyyskysymys
oltava_alueella($file, $table, $id);

if (($take != '') && saa_tehda("$file:take")) {
  $ret = hlo_take_to_paivystys_ok($herja,$id);
  if ($ret != 2) {
    ilmoita_jos_tarpeen($id);
    $now = date('Y-m-d H:i:s');
    # asetetaan ryhma ja tila vain jos henkil ei ennestn kuulu thn
    # operaatioon. tilaksi tulee "Paikalla".
    $sql =
      "UPDATE hlo
       SET ryhma_id=1,
           hlo_tila_id=3,
           ts='$now'
       WHERE id=$id AND paivystys_id != " . s("paivystys");
    $result = my_mysql_query ($sql,true,true);
    $sql =
      "UPDATE hlo
       SET paivystys_id=" . s("paivystys") . ",
           halyssa=1,
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    taktinen_loki("Otettu henkil " . ota_nimi($id));
    add_hlo_ajat($id);
    echo "<p>Henkil otettu thn operaatioon.\n";
  }
  p_herja($ret,$herja);
 }

if (($release != '') && saa_tehda("$file:release")) {
  $ret = hlo_release_from_paivystys_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE hlo
       SET ryhma_id=1, hlo_tila_id=5, halyssa=0, ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    add_hlo_ajat($id);
    $sql =
      "UPDATE hlo
       SET paivystys_id=1, ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql,true,true);
    add_hlo_ajat($id);
    taktinen_loki("Vapautettu henkil " . ota_nimi($id));
    echo "<p>Henkil vapautettu.\n";
  }
  p_herja($ret,$herja);
 }


echo "<form action=\"\" method=\"GET\">\n";

echo "<input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

$sql =
  "SELECT hlo.id, hlo.nimi, hlo.puhelin, hlo_tila.hlo_tila,
          hlo.ra, hlo.ts, hlo.paivystys_id, ryhma.kutsu, jarjesto
   FROM hlo, hlo_tila, ryhma, jarjesto
   WHERE (hlo.alue_id = 2
          OR hlo.alue_id = (SELECT paivystys.alue_id
                            FROM paivystys
                            WHERE id = " . s("paivystys") . "))
         AND hlo_tila.id = hlo.hlo_tila_id
         AND ryhma.id = hlo.ryhma_id
         AND jarjesto.id = hlo.jarjesto_id
   ORDER BY hlo.nimi";

$result = my_mysql_query($sql);
if ($result) {
    echo "<p><TABLE BORDER=1>\n";
    echo tr_bgcolor()
      . "<TH>Nimi<TH>Jrjest<TH>Operaatio<TH>Ryhm"
      . "<TH>Muutettu<TH>Tila<TH>Listieto\n";
    while ($a = mysql_fetch_array($result)) {
      $p_id = $a['paivystys_id'];
      $s_id = s('paivystys');
      if (($show == '')
	  || ($show == '1' && ($p_id != $s_id))
	  || ($show == '2' && ($p_id == 1))
	  || ($show == '3' && ($p_id == $s_id))
	  ) {
	echo "<TR>", "<TD>$a[nimi]",
	  "<td>$a[jarjesto]",
	  "<td>" . nayta_operaatio($p_id),
	  "<TD>$a[kutsu]", 
	  "<TD>$a[ts]", 
	  "<td>$a[hlo_tila]",
	  "<TD>$a[ra]";
	if ($p_id == $s_id) {
	  echo "<td>"
	    . "<a href=\"hlo-oper.php?id=$a[id]&show=$show&release=VAPAUTA\">"
	    . "VAPAUTA</a>\n";
	} else {
	  echo "<td>"
	    . "<a href=\"hlo-oper.php?id=$a[id]&show=$show&take=OTA\">"
	    . "OTA</a>\n";
	}
      }
    }
    echo "</TABLE>";
} 

echo "</form>\n";

echo "
<p>Voit ottaa henkiln tmn operaation kyttn klikkaamalla kohtaa OTA
(toimii mys muihin operaatioihin merkittyihin henkilihin).
<p>Henkil vapautetaan tmn operaation kytst klikkaamalla VAPAUTA. Et voi
vapauttaa henkil, joka ei kuulu thn operaatioon.
<p>Operaatio-sarakkeessa <font color=red>punaisella</font> on merkitty muut
operaatiot. Tmn operaation henkilkunta on merkitty
<font color=green>vihrell</font>. Vapaat on merkitty tll vrill.
";

echo "
<ul>Vaihtoehtoisia nkymi thn sivuun
<li><a href=\"hlo-oper.php?show=\">
  Nyt kaikki
 </a> (oletus)
<li><a href=\"hlo-oper.php?show=1\">
  Nyt vain henkilt jotka ovat vapaita tai toisessa operaatiossa
 </a> (kaikki otettavissa olevat)
<li><a href=\"hlo-oper.php?show=2\">
  Nyt vain henkilt jotka ovat vapaita
 </a>
<li><a href=\"hlo-oper.php?show=3\">
  Nyt vain henkilt jotka ovat tss operaatiossa
 </a> (kaikki vapautettavissa olevat)
</ul>";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: hlo-oper.php,v 1.19 2009/06/06 15:43:52 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/hlo-oper.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "hlo";
$file = basename(__FILE__);

include "common.php";
include "hlo-ok.php";

echo "
<html>
<head>
 <title>VIHA - Operaation miehittminen</title>
</head>
" . body_bgcolor() . "
<h1>" . muotoile_operaatio() . ", operaation miehittminen</h1>
";

taktiset_linkit();

$id = get_nro_0('id');

$take = get_txt('take');
$release = get_txt('release');
$show = get_nro('show');

# kuka vaan voi ottaa henkiln alueeltaan - kytettvyyskysymys
oltava_alueella($file, $table, $id);

if (($take != '') && saa_tehda("$file:take")) {
  $ret = ota_hlo_paivystys($herja, $id, s("paivystys"));
  if ($ret != 2) {
    $tmp_nimi = ota_nimi($id);
    tehty("Otettu $tmp_nimi thn operaatioon.");
  }
  p_herja($ret,$herja);
 }

if (($release != '') && saa_tehda("$file:release")) {
  $ret = vapauta_hlo_paivystys($herja,$id,s("paivystys"));
  if ($ret != 2) {
    $tmp_nimi = ota_nimi($id);
    tehty("Vapautettu $tmp_nimi.");
  }
  p_herja($ret,$herja);
 }


echo "<form action=\"\" method=\"GET\">\n";

echo "<input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

$sql =
  "SELECT hlo.id, hlo.nimi, hlo.puhelin, hlo_tila.hlo_tila,
          hlo.ra, hlo.ts, hlo.paivystys_id, ryhma.kutsu, jarjesto
   FROM hlo, hlo_tila, ryhma, jarjesto
   WHERE (hlo.alue_id = 2
          OR hlo.alue_id = (SELECT paivystys.alue_id
                            FROM paivystys
                            WHERE id = " . s("paivystys") . "))
         AND hlo_tila.id = hlo.hlo_tila_id
         AND ryhma.id = hlo.ryhma_id
         AND jarjesto.id = hlo.jarjesto_id
   ORDER BY hlo.nimi";

$result = my_mysql_query($sql);
if ($result) {
    echo "<p><TABLE BORDER=1>\n";
    tr_reset();
    echo tr_vaalsin()
      . "<TH>Nimi<TH>Jrjest<TH>Operaatio<TH>Ryhm"
      . "<TH>Muutettu<TH>Tila<TH>Listieto\n";
    while ($a = mysql_fetch_array($result)) {
      $p_id = $a['paivystys_id'];
      $s_id = s('paivystys');
      if (($show == '')
	  || ($show == '1' && ($p_id != $s_id))
	  || ($show == '2' && ($p_id == 1))
	  || ($show == '3' && ($p_id == $s_id))
	  ) {
	echo tr() . "<TD>$a[nimi]",
	  "<td>$a[jarjesto]",
	  "<td>" . nayta_operaatio($p_id),
	  "<TD>$a[kutsu]", 
	  "<TD>$a[ts]", 
	  "<td>$a[hlo_tila]",
	  "<TD>$a[ra]";
	if ($p_id == $s_id) {
	  echo "<td>"
	    . "<a href=\"hlo-oper.php?id=$a[id]&show=$show&release=VAPAUTA\">"
	    . "VAPAUTA</a>\n";
	} else {
	  echo "<td>"
	    . "<a href=\"hlo-oper.php?id=$a[id]&show=$show&take=OTA\">"
	    . "OTA</a>\n";
	}
      }
    }
    echo "</TABLE>";
 } 

echo "</form>\n";

echo "
<p>Voit ottaa henkiln tmn operaation kyttn klikkaamalla kohtaa OTA
(toimii mys muihin operaatioihin merkittyihin henkilihin).
<p>Henkil vapautetaan tmn operaation kytst klikkaamalla VAPAUTA. Et voi
vapauttaa henkil, joka ei kuulu thn operaatioon.
<p>Operaatio-sarakkeessa <font color=red>punaisella</font> on merkitty muut
operaatiot. Tmn operaation henkilkunta on merkitty
<font color=green>vihrell</font>. Vapaat on merkitty tll vrill.
";

echo "
<ul>Vaihtoehtoisia nkymi thn sivuun
<li><a href=\"hlo-oper.php?show=\">
  Nyt kaikki
 </a> (oletus)
<li><a href=\"hlo-oper.php?show=1\">
  Nyt vain henkilt jotka ovat vapaita tai toisessa operaatiossa
 </a> (kaikki otettavissa olevat)
<li><a href=\"hlo-oper.php?show=2\">
  Nyt vain henkilt jotka ovat vapaita
 </a>
<li><a href=\"hlo-oper.php?show=3\">
  Nyt vain henkilt jotka ovat tss operaatiossa
 </a> (kaikki vapautettavissa olevat)
</ul>";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: hlo-oper.php,v 1.27 2009/10/01 16:35:58 riku Exp $ -->
